#
# spec file
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global modname PyICU
Name:           python-%{modname}
Version:        2.7.4
Release:        bp155.2.13
Summary:        Python Extension Wrapping the ICU C++ API
License:        MIT
Group:          Development/Libraries/Python
URL:            https://gitlab.pyicu.org
Source0:        https://files.pythonhosted.org/packages/source/P/PyICU/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
Provides:       %{modname} = %{version}
Provides:       python-ICU = %{version}
Obsoletes:      python-ICU < 1.2
%python_subpackages

%description
Python extension wrapping IBM's International Components for Unicode C++
library (ICU).

%prep
%setup -q -n %{modname}-%{version}

%build
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch -v -k 'not (testAcceptLanguage or testAcceptLanguageFromHTTP)' -rs test

%files %{python_files}
%license LICENSE
%doc CHANGES CREDITS README.md
%{python_sitearch}/*

%changelog
* Mon Aug 16 2021 Axel Braun <axel.braun@gmx.de>
- %%pytest_arch added to fix Leap test issues
* Fri Aug 13 2021 Axel Braun <axel.braun@gmx.de>
-  2.7.4
  - added wrappers for UWordBreak and BreakIterator.getRuleStatusVec()
  - added wrappers for MessagePattern (Roman Kalukiewicz)
  - added wrapper for Collator::getKeywordValuesForLocale
  - added wrappers for LocaleMatcher.acceptLanguage|FromHTTP()
  - worked around limitation of Visual Studio 2017 (cgohlke)
  - added missing test and samples files to distribution (foutrelis)
  - added some tests for TimeZone classes
  - fixed bug w/FormattedNumberRange.getFirst|SecondDecimal() gone w/ ICU 68.1+
  - fixed bug with VTimeZone.write() wrapper invoking VTimeZone.writeSimple()
  - added wrapper for Locale.canonicalize()
  - added wrappers for MeasureUnit.product(), reciprocal(), getDimensionality()
  - added wrapper for MeasureUnit.forIdentifier()
  - implemented *, /, **, 1/m for MeasureUnit in terms of product and reciprocal
  - added wrappers for BasicTimeZone, RuleBasedTimeZone, VTimeZone
  - added wrappers for TimeZoneTransition, TimeZoneRule and its subclasses
  - added wrappers for DateTimeRule, DateRuleType, TimeRuleType
  - added support for ICU 69.1 (support-icu-69.patch reomoved)
* Wed Apr 28 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-icu-69.patch:
  * Support ICU 69
* Mon Dec 14 2020 Callum Farmer <gmbr3@opensuse.org>
- update to 2.6
  * fix build with ICU 68
* Fri Mar 27 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2.4.3
  * added Char.getPropertyValueName() and Char.getPropertyValueEnum()
  * fixed build errors with PythonReplaceable for ICU < 55
* Wed Jan 15 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2.4.2
  * fixed build issues with ICU < 59
  * lots of small fixes
* Mon Apr 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.3.1:
  * fixed build error with ICU 61, ICU 62
* Mon Apr  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.3:
  - added support for also trying pkg-config for build configuration (Linux)
  - fixed compilation issue in collator.cpp when not using c++11 (and icu < 60)
  - added support for ICU 64.1
  - filled out wrappers for missing NumberFormatter methods and classes
* Thu Nov  1 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 2.2:
  * Many fixes to build well with newest ICU releases
- Drop not really needed service
- Cleanup with spec-cleaner
* Wed Jan 24 2018 mlin@suse.com
- Update to 2.0.2
  * Added wrappers for Region class and URegionType enum
  * Added wrappers for MeasureFormat.formatMeasure and formatMeasurePerUnit
  * Fixed build error with ICU < 53
- Update the URL
- Removed unneed python-PyICU-1.9.7-quote_Version.patch
- Running test on python3 only, upstream has problem with running test on
  python2, upstream issue #61
* Wed Jan 24 2018 mlin@suse.com
- Update to 2.0.1
  * Made Measure wrapper abstract when building with ICU < 53.1
  * str(Measure) uses NumberFormatter when available
* Wed Jan 24 2018 mlin@suse.com
- Update to 2.0.0
  * Use icu-config for configuring compiler and linker (Constantine Peresypkin)
  * Added wrappers for UBidiPairedBracketType enum
  * Added wrappers for UWordBreakValues enum
  * Added wrappers for UJoiningGroup enum
  * Added wrappers for 120+ MeasureUnit static factory methods
  * Added wrapper for NoUnit class
  * Added wrapper for TimeUnit class
  * Added missing Measure constructor(Formattable or number, MeasureUnit)
  * Added wrappers for NumberFormatter and related classes and enums, and tests
  * Added wrapper for SimpleFormatter and tests
  * Fixed bugs in test_LocaleData.py using undefined values (Fredrik Roubert)
  * Added wrapper for UMemory and made it UObject's base
  * Removed unused docs.py
* Wed Jan 24 2018 mlin@suse.com
- Update to 1.9.8
  * Fixed bugs in "UnicodeString as sequence"; it's a sequence of 16-bit UChar
  * Added support for ICU 60.1
* Thu Jun  8 2017 okurz@suse.com
- Update to 1.9.7
  * Remove dependency on deprecated and removed ICU LayoutEngine
* Tue May 12 2015 lazy.kent@opensuse.org
- Update to 1.9.2 (excluding openSUSE 11.4).
  * Added MANIFEST.in to ensure nothing's missing in the 'sdist'
    package.
  * Enabled -Wwrite-strings and fixed warnings.
  * Added missing conditionals around uses of features in newer ICU
    versions.
- Changes in 1.9.
  * Fixed utf-8 conversion error position reporting.
  * Fixed delete/delete[] bug in common.cpp.
  * Added support for ICU 54.1 and ICU 55.1.
  * Replaced UnicodeString idna methods with new uidna.h UTS #46
    wrapper (55.1).
  * Added wrapper for Char functions and related enums (from
  * uchar.h).
  * Added wrapper for Shape defines and shapeArabic() (from
    ushape.h).
  * Added wrapper for RelativeDateTimeFormatter.
- Drop the source and the patch for openSUSE 12.3.
* Sat Aug  2 2014 lazy.kent@opensuse.org
- Update to 1.8 (excluding openSUSE 11.4 and 12.3).
  * Added wrapper for Locale::getRoot().
  * Added tp_hash implemention for Locale type based on
    Locale::hashCode().
  * Fixed bug 13112.
  * Added support for building with PyPy.
  * Added Locale(lcid) constructor calling uloc_getLocaleForLCID().
  * Added wrapper for CompactDecimalFormat and its createInstance()
    method.
- Changes in 1.7.
  * Added missing #include for <unicode/uscript.h>.
  * Fixed issues building against ICU 4.2.
  * Added wrapper for Script.isRightToLeft().
  * Added support for ICU 53.1.
  * Added wrappers for other Script functions introduced in ICU 51.
- Changes in 1.6.
  * Removed wrappers for some layoutengine.cpp internal flags.
  * Added wrappers for ULocaleData functions.
  * Added wrappers for uscript functions and UScriptCode enum.
  * Added support for ICU 52.1.
  * Added wrapper for Locale::setKeywordValue().
  * Added Locale::removeKeywordValue().
  * Added support for ListFormatter.
- Change BuildRequires: python-distribute -> python-setuptools.
* Fri Mar 15 2013 lazy.kent@opensuse.org
- Update to 1.5 (excluding openSUSE 11.4 and 12.1).
  * Added wrapper for MessageFormat::format(argumentNames,
    arguments, ...).
  * Fixed bug in t_transliterator_filteredTransliterate passing
    UBool for int.
  * Added wrapper for DateFormat::format(Calendar).
  * Added wrapper for Calendar::set(UCalendarDateFields field,
    value).
  * Added wrappers for UnicodeString::toTitle() w/o iterator.
  * Added support for ICU 50.1.
  * Improved test_Collator's testGetSortKey().
  * Added pypi classifiers to PyICU project info.
- Use pkgconfig(*) as build dependencies.
- Don't use "--record-rpm" during install; add to %%files section.
* Wed Jul 18 2012 lazy.kent@opensuse.org
- Fix suse_version for Factory (12.3).
* Wed Apr 18 2012 lazy.kent@opensuse.org
- Update to 1.4.
  * Added support for ICU 49.1.1.
  * Added ScriptCode constants new in 49.0.
  * Implemented wrapper for new NumberFormat.parseCurrency().
  * Added wrapper for Transliterator::toRules().
  * Added missing wrapper for
    RuleBasedNumberFormat(URBNFRuleSetTag, Locale).
  * Fixed bugs.
- Changes in 1.3.
  * Added support for ICU 4.8.1.1.
  * PyICU ready for Python 3.2.
  * Added support for LEFontInstance and LayoutEngine.
  * Fixed bugs.
- Refresh "quote_Version" patch.
- Run tests.
- Patch to fix running tests in openSUSE 11.4.
* Wed Nov  9 2011 lazy.kent@opensuse.org
- Build reqiures python-setuptools or python-distribute (for
  openSUSE >= 12.1).
- spec clean up.
* Wed Sep 21 2011 lazy.kent@opensuse.org
- Update to 1.2.
  * Fixed bugs.
- Dropped "linux3" patch (no need any more).
- Removed obsolete "clean" section and Authors from spec.
* Sat Jul 23 2011 lazy.kent@opensuse.org
- Patch to fix compilation on linux3 platform.
- Use python-setuptools.
- Added LICENSE to docs.
* Mon May 30 2011 lazy.kent@opensuse.org
- Renamed to python-PyICU.
* Sat May 28 2011 lazy.kent@opensuse.org
- Update to 1.1.
- Dropped undefine_DATE patch.
- Refresh quote_Version patch.
- Provides PyICU.
* Thu Feb 17 2011 pth@suse.de
- pyconfig.h defines DATE which breaks ICU's calendar.h
- Fix quoting of PYICU_VER.
* Sun Oct 17 2010 lazy.kent.suse@gmail.com
- Update to 1.0.1.
* Sat Sep 25 2010 lazy.kent.suse@gmail.com
- Update to 1.0.
* Tue Apr  6 2010 lazy.kent.suse@gmail.com
- Initial package created.
